/*
Copyright (c) 1998-2009 VIA Technologies, Inc. All Rights Reserved.
 
This PROPRIETARY SOURCE CODE contains proprietary information of VIA 
Technologies, Inc. (VIA); Contents of this file shall not be disclosed to any 3rd party, 
copied or duplicated in any form, in whole or in part without prior written consent of 
VIA.  THIS SOURCE CODE & ANY RELATED DOCUMENTATION 
(COLLECTIVELY SOFTWARE) ARE PROVIDED AS IS, WITH ALL FAULTS, & 
WITHOUT WARRANTY OF ANY KIND.  VIA DISCLAIMS ALL EXPRESS OR 
IMPLIED WARRANTIES.  USER ACKNOWLEDGES THAT PARTIES FOR ANY 
DAMAGES ARISING FROM USE OF SOFTWARE OR ITS DERIVATIVE, 
INCLUDING, W/O LIMITATION, LOSS OF USE, DATA OR PROFITS. USER
WHOLLY ASSUMES ALL RISK ARISING FROM USE & PERFORMANCE OF 
SOFTWARE
*/ 
 
#ifndef FDAPI_WDT_H_
#define FDAPI_WDT_H_

#include "fdapi_base.h"

#ifdef __cplusplus
extern "C" {
#endif

/************************************************************************
  watchdog timer
************************************************************************/

/**
 * The board supports watchdog timer function or not
 * @return   : Returns TRUE if support or FALSE otherwise.
 */
FLITEDECK_API BOOL FDSdk_SupportWdt(void);

/**
 * Start watch dog timer function
 * @return   : Returns FD_S_OK if successful or FD_E_FAIL otherwise.
 */
FLITEDECK_API DWORD FDWdt_Start(void);
/**
 * Stop watch dog timer function
 * @return   : Returns FD_S_OK if successful or FD_E_FAIL otherwise.
 */
FLITEDECK_API DWORD FDWdt_Stop(void);
/**
 * Refresh watch dog timer function
 * @return   : Returns FD_S_OK if successful or FD_E_FAIL otherwise.
 */
FLITEDECK_API DWORD FDWdt_Refresh(void);
/**
 * Set seconds of delay and timeout
 * @param byTimeOut: the seconds of of timeout
 * @return   : Returns FD_S_OK if successful or FD_E_FAIL otherwise.
 */
FLITEDECK_API DWORD FDWdt_SetTimer(BYTE byTimeOut);

/**
 * Get seconds of watchdog timer 
 * @param pdwTimer: a pointer to a buffer that receives the seconds of timer.
 * @return   : Returns FD_S_OK if successful or FD_E_FAIL otherwise.
 */
FLITEDECK_API DWORD FDWdt_GetTimer(DWORD* pdwTimer);

typedef enum {
	WDT_ACTION_RESET = 0,	///< default action, system reset if watchdog timer is timeout.
	WDT_ACTION_POWER_OFF,	///< system power off if watchdog timer is timeout.
} TWdtAction;

/**
 * Set system action if watchdog timer is timeout.
 * @param dwAction: refer TWdtAction
 * @return   : Returns FD_S_OK if successful or FD_E_FAIL otherwise.
 * @remarks  : FD_E_FAIL means the board does not support the action.
 *             if user didn't set the action, WDT_ACTION_RESET is default.
 */
FLITEDECK_API DWORD FDWdt_SetAction(DWORD dwAction);

/**
 * Get system action if watchdog timer is timeout.
 * @param pdwAction: refer TWdtAction
 * @return   : Returns FD_S_OK if successful or FD_E_FAIL otherwise.
 */
FLITEDECK_API DWORD FDWdt_GetAction(DWORD* pdwAction);

#ifdef __cplusplus
} // extern C
#endif

#endif
